--------------------------------------------------------------------------------
-- Weapon Bomb + Projectile Bomb
-- Original Carnage Contest Weapon
-- Script by DC, August 2009, www.UnrealSoftware.de
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.Bomb={}
cc.Bomb.Bomb={}

-- Load & Prepare Ressources
cc.Bomb.gfx_wpn=loadgfx("weapons/rc.bmp")								-- Weapon Image
setmidhandle(cc.Bomb.gfx_wpn)
cc.Bomb.gfx_pro=loadgfx("weapons/airbomb.bmp")							-- Projectile Image
setmidhandle(cc.Bomb.gfx_pro)
cc.Bomb.sfx_hit=loadsfx("explosion6.ogg")
cc.Bomb.sfx_attack=loadsfx("airstrike.ogg")								-- Attack sound

--------------------------------------------------------------------------------
-- Weapon: Bomb
--------------------------------------------------------------------------------

cc.Bomb.id=addweapon("cc.Bomb","Bomb",cc.Bomb.gfx_pro,0,3)		-- Add Weapon (0 uses, first in round 3)

function cc.Bomb.draw()											-- Draw
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	drawinhand(cc.Bomb.gfx_wpn,7,0)
	-- HUD Positioning
	if weapon_shots==0 then
		hudpositioning(pos_invisible)
	end
end

function cc.Bomb.attack(attack)									-- Attack
	if (weapon_shots<=0) and (weapon_position==1) then
		-- No more weapon switching!
		useweapon(0)
		playsound(cc.Bomb.sfx_attack)
		weapon_shots=weapon_shots+1
		-- Attack
		pid=createprojectile(cc.Bomb.Bomb.id)
		projectiles[pid]={}
		projectiles[pid].x=weapon_x
		projectiles[pid].y=-500
		projectiles[pid].sx=0
		projectiles[pid].sy=3.0
		-- End Turn
		endturn()
	end
end

--------------------------------------------------------------------------------
-- Projectile: Bomb
--------------------------------------------------------------------------------

cc.Bomb.Bomb.id=addprojectile("cc.Bomb.Bomb")	-- Add Projectile

function cc.Bomb.Bomb.draw(id)							-- Draw
	-- Setup draw mode
	setblend(blend_alpha)
	setalpha(1)
	setcolor(255,255,255)
	setscale(1,1)
	setrotation(0)
	-- Draw projectile
	drawimage(cc.Bomb.gfx_pro,projectiles[id].x,projectiles[id].y)
end

function cc.Bomb.Bomb.update(id)							-- Update
	-- Particle Tail
	particle(p_smoke,projectiles[id].x,projectiles[id].y)
	particlespeed(math.random(-2,2)*0.1,math.random(-2,2)*0.1)
	particlefadealpha(0.05)
	-- Gravity influence on speed
	projectiles[id].sy=projectiles[id].sy+getgravity()
	-- Move (in substep loop for optimal collision precision)
	msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/2)
	msubx=projectiles[id].sx/msubt
	msuby=projectiles[id].sy/msubt
	for i=1,msubt,1 do
		projectiles[id].x=projectiles[id].x+msubx
		projectiles[id].y=projectiles[id].y+msuby
		-- Collision
		if collision(col3x3,projectiles[id].x,projectiles[id].y,1,1)==1 then
				playsound(cc.Bomb.sfx_hit)
				terrainexplosion(projectiles[id].x,projectiles[id].y,60,1)
				-- Cause damage
				arealdamage(projectiles[id].x,projectiles[id].y,125,65)
			-- Crater
			grey=math.random(0,40)
			if math.random(0,1)==1 then
				terrainalphaimage(gfx_crater150,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
			else
				terrainalphaimage(gfx_crater175,projectiles[id].x,projectiles[id].y,math.random(6,9)*0.1,grey,grey,grey)
			end
				-- Particles
				for j=1,30,1 do
					particle(p_smoke,projectiles[id].x,projectiles[id].y)
					particlespeed(math.random(-10,10)*0.1,math.random(-10,10)*0.1)
					particlefadealpha(0.01)
				end
				-- Free projectile
				freeprojectile(id)
			end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			playsound(sfx_hitwater1)
			-- Free projectile
			freeprojectile(id)
		end
	-- Scroll to projectile
	scroll(projectiles[id].x,projectiles[id].y)
	end
end