--------------------------------------------------------------------------------
-- Weapon Bullet Rain + Projectile Bullet
-- Script by Arne, September 2010
--------------------------------------------------------------------------------

-- Setup Tables
if cc==nil then cc={} end
cc.bulletrain={}
cc.bulletrain.bullet={}

-- Load & Prepare Ressources
cc.bulletrain.gfx_wpn=loadgfx("weapons/bulletrain.png")					-- Weapon Image
setmidhandle(cc.bulletrain.gfx_wpn)
cc.bulletrain.gfx_pro=loadgfx("weapons/shot.bmp")						-- Projectile Image
setmidhandle(cc.bulletrain.gfx_pro)

--------------------------------------------------------------------------------
-- Weapon: Bullet Rain
--------------------------------------------------------------------------------

cc.bulletrain.id=addweapon("cc.bulletrain","Bullet Rain",cc.bulletrain.gfx_wpn,0,3)	-- Add Weapon (0 uses, first in round 3)

function cc.bulletrain.draw()											-- Draw
	-- Fade Dark
	if weapon_shots>0 and weapon_timer<0.4 then
		weapon_timer=weapon_timer+0.01
	end
end

function cc.bulletrain.attack(attack)									-- Attack
	if (weapon_shots<=0) and (attack==1) then
		-- No more weapon switching!
		useweapon(0)
		weapon_shots=weapon_shots+1
		-- Random Seed
		math.randomseed(getplayerx(0)*374+getplayery(0)*56+getframe()*123+getround()*98)
		-- Spawn Bullets (amount depending on map size)
		limit=math.ceil(getmapwidth()/1)
		if limit>800 then
			limit=800
		end
		for i=1,limit,1 do
			pid=createprojectile(cc.bulletrain.bullet.id)
			projectiles[pid]={}
			projectiles[pid].x=math.random(0,getmapwidth())
			projectiles[pid].y=-math.random(500,650)
			projectiles[pid].sx=math.random(-40,40)*0.1
			projectiles[pid].sy=math.random(150,200)*0.1
			projectiles[pid].timer=i*math.random(2,3)
		end
		-- End Turn
		endturn()
	end
end

--------------------------------------------------------------------------------
-- Projectile: Bullet
--------------------------------------------------------------------------------

cc.bulletrain.bullet.id=addprojectile("cc.bulletrain.bullet")		-- Add Projectile

function cc.bulletrain.bullet.draw(id)							-- Draw
	setbgcolor(0,0,0,weapon_timer,0.01)
	if projectiles[id].timer<=0 then
		-- Setup draw mode
		setblend(blend_alpha)
		setalpha(1)
		setcolor(255,255,0)
		setscale(1,1)
		-- Calculate projectile rotation
		setrotation(math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy)))
		-- Draw projectile
		drawimage(cc.bulletrain.gfx_pro,projectiles[id].x,projectiles[id].y)
	end
end

function cc.bulletrain.bullet.update(id)							-- Update
	-- Timer
	if projectiles[id].timer>0 then
		-- Count Down before bullet appears
		projectiles[id].timer=projectiles[id].timer-1
		if projectiles[id].timer==0 then
		end
	else
		rot=math.deg(math.atan2(projectiles[id].sx,-projectiles[id].sy))
		-- Move (in substep loop for optimal collision precision)
		msubt=math.ceil(math.max(math.abs(projectiles[id].sx),math.abs(projectiles[id].sy))/3)
		msubx=projectiles[id].sx/msubt
		msuby=projectiles[id].sy/msubt
		for i=1,msubt,1 do
			projectiles[id].x=projectiles[id].x+msubx
			projectiles[id].y=projectiles[id].y+msuby		
		-- Collision
		if collision(col3x3,projectiles[id].x+math.sin(math.rad(rot))*20,projectiles[id].y-math.cos(math.rad(rot))*20,1,1)==1 then
			if terraincollision()==1 or playercollision()~=projectiles[id].ignore then
				-- Cause damage
				if playercollision()~=0 then
					playerpush(playercollision(),projectiles[id].sx/10.0,projectiles[id].sy/10.0)
					playerdamage(playercollision(),10)
					blood(projectiles[id].x+math.sin(math.rad(rot))*20,projectiles[id].y-math.cos(math.rad(rot))*20)
				end
				-- Destroy terrain
				for j=20,22,1 do
					terraincircle(projectiles[id].x+math.sin(math.rad(rot))*j,projectiles[id].y-math.cos(math.rad(rot))*j,3,0x00000000)
				end
				-- Effects
				playsound(sfx_ricochet1)
				particle(p_smoke,projectiles[id].x+math.sin(math.rad(rot))*21,projectiles[id].y-math.cos(math.rad(rot))*21)
				particlefadealpha(0.006)
				particle(p_muzzle,projectiles[id].x+math.sin(math.rad(rot))*21,projectiles[id].y-math.cos(math.rad(rot))*21)
				-- Free projectile
				freeprojectile(id)
				return 1
			end
		else
			projectiles[id].ignore=0
		end
		-- Water
		if (projectiles[id].y)>getwatery()+5 then
			-- Effects
			particle(p_waterhit,projectiles[id].x,projectiles[id].y)
			if math.random(1,2)==1 then
				playsound(sfx_hitwater2)
			else
				playsound(sfx_hitwater3)
			end
			-- Free projectile
			freeprojectile(id)
			return 1
			end
		end
	end
end